.. _help:

Get Help
========

Welcome to the Falcon community! We are a pragmatic group of HTTP enthusiasts
working on the next generation of web apps and cloud services. We would love
to have you join us and share your ideas.

Please help us spread the word and grow the community!

IRC
---
While you experiment with Falcon and work to familiarize yourself with
the WSGI framework, please consider joining the **#falconframework**
IRC channel on
`Freenode <https://en.wikipedia.org/wiki/Freenode>`_. It's a great place to
ask questions, share ideas, and get the scoop on what's new.

.. include:: contrib-snip.rst
